#!/usr/bin/perl
use lib '/home/martin/ethereal/mgmt';

#################################################################################
# Created       : Martin Foster
# Modified      : 03-May-2004
#################################################################################
#
# Forecast - Forecast generator part of Ethereal Realms that will display out to
#            Javascript for use outside the site proper.
# Copyright (C) 2000-2006  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 29-26503 TWP RD 511
#                 Spruce Grove, Alberta
#                 T7Y 1G4
#
#################################################################################

use CGI qw(:standard);						# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use strict;							# Strict variable enforcement

use Ethereal::Database;						# Database handler
use Ethereal::Param;						# Parameter control
use Ethereal::Template;						# Templating capabilities
use Ethereal::Weather;						# Weather handler


#################################################################################
# Data Members
#################################################################################
my $cgi;							# Common gateway interface handle
my $database;							# Database handle
my $for;							# Forecast handle
my $param;							# Parameter list
my $tmpl;							# Templating handle

my $concat;							# Concatenated line
my $cond;							# Weather conditions
my $key;							# Key for conditions
my $metar;							# Natural state of forecast
my $sky;							# Sky conditions

my %cond;							# Specific condition
my %portal;							# Portal hash

#################################################################################
# Program Area
#################################################################################

	# Initial handles
	$cgi      = new CGI;
	$database = new Ethereal::Database();

	# Connect and fetch
	$database->Connect($cgi);	

	# Parameter handling
	$param = new Ethereal::Param($database, $cgi);
	$param->GetParam();
	

	# Display header
	print $cgi->header('text/javascript');

	# Validity
	if ((defined($param->{'ICAO'}))
	 && ($param->{'ICAO'} =~ /^\w+$/))
 	{
		# Pull forecast
		($metar) = $database->DataGetWeatherICAO($param->{'ICAO'});	

		# Valid forecast
		if (defined($metar))
		{
			# Populate hash
			$database->GetHashPortal(\%portal);
			
			# Initialize handle
			$for  = new Ethereal::Weather();
			$tmpl = new Ethereal::Template(\%portal);

			
			# Weather
			# Parse
			$for->Parse($metar, \%cond);

			# Forcast handling
			$sky  = lc(join(", ", @{$cond{SKY}}));
			$cond = lc(join(", ", @{$cond{HUMAN}}));		

			# Conditions
			$cond = (length($cond) > 2) ? ucfirst("$cond, $sky") : ucfirst("$sky");
			$cond =~ s/,([^,.]+?)$/ and $1/s;


			# Check values
			foreach $key (keys(%cond))
			{
				# Verify conditions
				$cond{$key} = (defined($cond{$key})) ? $cond{$key} : $portal{'TxtUnavail'};
			}
		

			# Display
			# Simply replace template
			$concat = $tmpl->Pass('TmplWeather',
				MFORECAST       => $cond,
				MWIND_DIR_ENG	=> $cond{'WIND_DIR_ENG'},
				MWIND_KPH	=> $cond{'WIND_KPH'},
				MWIND_MPH	=> $cond{'WIND_MPH'},
				MC_DEW		=> $cond{'C_DEW'},
				MF_DEW		=> $cond{'F_DEW'},
				MC_TEMP		=> $cond{'C_TEMP'},
				MF_TEMP		=> $cond{'F_TEMP'},
				MVIS_KILO	=> $cond{'VIS_KILO'},
				MVIS_MILE	=> $cond{'VIS_MILE'},
				MALTI		=> $cond{'ALTI'},
				MALTK		=> $cond{'ALTK'}
			 );

			# Modify lines
			$concat =~ s/(\n|\r)//gs;
			$concat =~ s/\s{2,}//gs;
			$concat =~ s/'/\\'/gs;

			# Display entry
			print "document.write('" . $concat . "');";
		}

		# Forecast is missing
		else
		{
			# Display error message
			print "document.write('<b>[ERROR: Forecast not tracked]</b>');";
		}
	}

	# Sound error
	else
	{
		# Through javascript
		print "document.write('<b>[ERROR: Invalid parameters]</b>');";
	}
